@@ -1,17 +1,14 @@
-use bin_layout::{lencoder::*, DataType};
+use bin_layout::{lencoder::*, Decoder, Encoder};
 
 #[test]
-fn test_lencoder_l2() {
+fn test_lencoder() -> Result<(), ()> {
     for num in 0..=L2::MAX {
-        // let mut buf = [0; 2];
-        assert_eq!(num, L2::decode(&L2(num).encode()).unwrap().0);
+        assert_eq!(num, L2::decode(&L2(num).encode())?.0);
     }
-}
-#[test]
-fn test_lencoder_l3() {
     for num in 0..=(L3::MAX / 3) {
-        assert_eq!(num, L3::decode(&L3(num).encode()).unwrap().0);
+        assert_eq!(num, L3::decode(&L3(num).encode())?.0);
     }
+    Ok(())
 }
 
 #[allow(unused)]
@@ -20,7 +17,7 @@ macro_rules! dbg_lencoder {
         let mut buf = [0; 4];
         $ty($num).encode(&mut buf).unwrap();
         let mut reader = buf.as_ref().into();
-        let decoded: $ty = DataType::deserialize(&mut reader).unwrap();
+        let decoded = (Decoder::decoder(&mut reader) as Result<$ty, ()>).unwrap();
         println!("\nNumber: {:?} ({:#X})", $num, $num);
         println!("Packed: {:b}\n", $num);
         println!("Encoded Bits:");
